# [0.4.9](https://github.com/seriaati/hakushin-py/compare/v0.4.8..v0.4.9) - 2025-03-01

## Bug Fixes

- Handle null values in LightCone description field - ([632f90b](https://github.com/seriaati/hakushin-py/commit/632f90b98869362ba1a6b0c976edc3be8278a215))

## Miscellaneous Chores

- **(deps)** lock file maintenance ([#71](https://github.com/seriaati/hakushin-py/issues/71)) - ([bf9278e](https://github.com/seriaati/hakushin-py/commit/bf9278ec5d191c6db79d6adbc23b6078c78a86f4))
- **(deps)** lock file maintenance ([#72](https://github.com/seriaati/hakushin-py/issues/72)) - ([d4569aa](https://github.com/seriaati/hakushin-py/commit/d4569aa1ef84b1a1f01e31f906a5c8c4fa447be3))

